#!/bin/sh

# THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
# 5724-I04 (C) COPYRIGHT International Business Machines Corp., 1997,2007
# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

echo ""
echo "IBM WebSphere Voice Server for Multiplatforms v 5.1.3.3"
echo "5724-I04 (C) COPYRIGHT International Business Machines Corp., 1997,2007"
echo "All Rights Reserved * Licensed Materials - Property of IBM"
echo "US Government Users Restricted Rights - Use, duplication or disclosure"
echo "restricted by GSA ADP Schedule Contract with IBM Corp."
echo ""

# set the environment

thisDir=`dirname "$0"`
if [ ${thisDir} = "." ]; then
  thisDir=`pwd`
fi

# check if current user is root
if [ $(whoami) != "root" ]; then
   echo "Installation program must be executed by root user."
   echo ""
   exit 10
fi


# attempt to load WebSphere AppServer configuration

if [ -f ${WAS_HOME}/bin/setupCmdLine.sh ]; then
  . ${WAS_HOME}/bin/setupCmdLine.sh
elif [ -f /usr/WebSphere/AppServer/bin/setupCmdLine.sh ]; then
  . /usr/WebSphere/AppServer/bin/setupCmdLine.sh
elif [ -f /opt/WebSphere/AppServer/bin/setupCmdLine.sh ]; then
  . /opt/WebSphere/AppServer/bin/setupCmdLine.sh
fi

# attempt to load WebSphere VoiceServer configuration

if [ -f ${WVS_HOME}/wvs.setenv ]; then
  . ${WVS_HOME}/wvs.setenv
elif [ -f /usr/WebSphere/VoiceServer/wvs.setenv ]; then
  . /usr/WebSphere/VoiceServer/wvs.setenv
elif [ -f /opt/WebSphere/VoiceServer/wvs.setenv ]; then
  . /opt/WebSphere/VoiceServer/wvs.setenv
fi

# check if attempts were successful to load/locate environment

if [ -z "${WAS_HOME}" ]; then
   echo "Did not locate WebSphere Application Server installation."
   echo "Please ensure WAS_HOME environment variable is set to the"
   echo "WebSphere Application Server installation root."
   echo "Refer to this program documentation (readme) for more information."
   echo ""
   exit 1
fi  

if [ -z "${WVS_ROOT}" ]; then
   echo "WVS_ROOT variable not set."
   echo "Please configure WebSphere Voice Server wvs.setenv according"
   echo "to the WVS InfoCenter."
   echo ""
   exit 2
fi

# detect WebSphere's Java Virtual Machine
export JAVA_HOME=${WAS_HOME}/java

if [ ! -d "${JAVA_HOME}" ]; then
   echo "WebSphere's Java(tm) Virtual Machine can't be located."
   echo "Please contact IBM support."
   echo ""
   exit 3
fi

# check for enough disk space in /tmp so we can attempt to copy JVM
# check for 200MB

tmpspace=`df -k -P /tmp | tail -1 | awk -F" " '{ printf("%d",$4) }'`
if [[ -n "${tmpspace}" && ${tmpspace} -lt 204800 ]]; then
  echo "Not enough space in /tmp to continue."
  echo "Please refer to the README for the minimum requirements."
  echo ""
  exit 4
fi

# # copy the JVM to the temp directory
# count=1
# prefix=/tmp/javatmp
# tmpjava=${prefix}${count}
# while [ -d "${tmpjava}" ]; do
#   count=$((${count}+1))
#   tmpjava=${prefix}${count}
# done
#
#echo "Please wait while we copy the Java(tm) Virtual Machine..."
#echo "This could take a few minutes."
#echo ""
#
#mkdir  ${tmpjava}
#cp -pR ${JAVA_HOME} ${tmpjava}
#
#if [ $? -ne 0 ]; then
#  echo "Failed to create a temporary copy of the Java(tm) Virtual Machine."
#  echo "Please ensure you have enough space in /tmp."
#  echo "Please refer to the README for the minimum requirements."
#  echo ""
#  rm -fr ${tmpjava}
#  exit 5
#fi
#export JAVA_HOME=${tmpjava}/java

# check if WVS is running
tmpfile=".install.proclist"
ps -eo "%p %a" |\
  grep -e engine -e asrcontrol -e ttsmcl -e ibmcmm |\
  grep -v "grep -e engine" > $tmpfile
procnbr=`cat $tmpfile | wc -l | sed "s/ //g"`
rm -f $tmpfile
if [ "${procnbr}" -ne 0 ]; then
  echo "WebSphere Voice Server processes detected."
  echo "Please stop this product prior to running this program."
  echo ""
  exit 6
fi
rm -f $tmpfile

# run slibclean in AIX
if [ $(uname) == "AIX" ]; then
  slibclean
fi

# make some changes for RedHat 3
if [ -f /etc/redhat-release ]; then
   rel3=`grep "release 3" /etc/redhat-release|wc -l|sed "s/ //g"`
   if [ $rel3 -gt 0 ]; then
     export LD_ASSUME_KERNEL=2.2.5
   fi
fi


# start the installation program
export PATH=${JAVA_HOME}/bin:${PATH}
exitcode=6

echo "Invoking Fix Pack installation program..."
echo "Please wait..."
echo ""

export WAS_HOME
export WVS_HOME

if [ -f ${thisDir}/install.bin ]; then
  chmod +x ${thisDir}/install.bin
  ${thisDir}/install.bin $*
  exitcode=$?
#elif [ -f "${thisDir}/install.jar" ]; then
#  props="-DWAS_HOME=${WAS_HOME}"
#  props="${props} -DWVS_ROOT=${WVS_ROOT}"
#  ${JAVA_HOME}/bin/java ${props} -jar ${thisDir}/install.jar $*
#  exitcode=$?
else
  echo "Error: file ${thisDir}/install.bin not found."
  echo ""
fi

if [ ${exitcode} -ne 0 ]; then
  echo "Installation program failed."
  echo "Exit code: "${exitcode}
  echo ""  
fi

# finished, clean up
#echo "Cleaning temporary files..."
#echo ""
#rm -fr ${tmpjava}

exit ${exitcode}
